@@ -126,39 +126,6 @@ impl GeneralReadout for NetBSDGeneralReadout {
     }
 
     fn resolution(&self) -> Result<String, ReadoutError> {
-        fn get_resolution_without_x() -> Result<String, ReadoutError> {
-            let drm = std::path::Path::new("/sys/class/drm");
-            if drm.is_dir() {
-                let dirs = extra::list_dir_entries(drm);
-                let mut resolution = String::new();
-                for entry in dirs {
-                    if entry.read_link().is_ok() {
-                        let modes = std::path::PathBuf::from(entry).join("modes");
-                        if modes.is_file() {
-                            if let Ok(mut this_res) = std::fs::read_to_string(modes) {
-                                if !this_res.is_empty() {
-                                    if this_res.ends_with("\n") {
-                                        this_res.pop();
-                                    }
-                                    resolution.push_str(&this_res);
-                                    resolution.push_str(", ");
-                                }
-                            }
-                        }
-                    }
-                }
-                if resolution.trim_end().ends_with(",") {
-                    resolution.pop();
-                }
-
-                Ok(resolution)
-            } else {
-                Err(ReadoutError::Other(String::from(
-                    "Could not obtain screen resolution from /sys/class/drm.",
-                )))
-            }
-        }
-
         if cfg!(feature = "xserver") {
             use std::os::raw::c_char;
             use x11_ffi::*;
@@ -177,12 +144,16 @@ impl GeneralReadout for NetBSDGeneralReadout {
                 }
 
                 return Ok(format!("{}x{}", width, height));
-            } else {
-                return get_resolution_without_x();
             }
-        } else {
-            return get_resolution_without_x();
+
+            Err(ReadoutError::Other(String::from(
+                "XOpenDisplay() returned null.",
+            )))
         }
+
+        Err(ReadoutError::Other(String::from(
+            "X11 is required to fetch screen resolution.",
+        )))
     }
 
     fn machine(&self) -> Result<String, ReadoutError> {
